Module uim.model.helpers
========================
Helpers
=======
The  helpers are simple functions to support with:

 - Catmull-Rom splines
 - Extracting text and named entities from Ink Model
 - Iterate over the Ink Tree

Sub-modules
-----------
* uim.model.helpers.policy
* uim.model.helpers.spline
* uim.model.helpers.text_extractor
* uim.model.helpers.treeiterator